package App::fsql;

our $VERSION = '0.12'; # VERSION
our $DATE = '2014-12-03'; # DATE

1;
# ABSTRACT: Perform SQL queries against files in CSV/TSV/LTSV/JSON/YAML formats

__END__

=pod

=encoding UTF-8

=head1 NAME

App::fsql - Perform SQL queries against files in CSV/TSV/LTSV/JSON/YAML formats

=head1 VERSION

This document describes version 0.12 of App::fsql (from Perl distribution App-fsql), released on 2014-12-03.

=head1 SYNOPSIS

See the command-line script L<fsql>.

=head1 HOMEPAGE

Please visit the project's homepage at L<https://metacpan.org/release/App-fsql>.

=head1 SOURCE

Source repository is at L<https://github.com/perlancar/perl-App-fsql>.

=head1 BUGS

Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=App-fsql>

When submitting a bug or request, please include a test-file or a
patch to an existing test-file that illustrates the bug or desired
feature.

=head1 AUTHOR

perlancar <perlancar@cpan.org>

=head1 COPYRIGHT AND LICENSE

This software is copyright (c) 2014 by perlancar@cpan.org.

This is free software; you can redistribute it and/or modify it under
the same terms as the Perl 5 programming language system itself.

=cut
